import { User } from '@jupyterlab/services';
import { DocumentChange, YDocument } from '@jupyter/ydoc';
import { IDocumentProvider, IDocumentProviderFactory } from './tokens';
/**
 * A class to provide Yjs synchronization over WebSocket.
 *
 * We specify custom messages that the server can interpret. For reference please look in yjs_ws_server.
 *
 */
export declare class WebSocketProvider implements IDocumentProvider {
    /**
     * Construct a new WebSocketProvider
     *
     * @param options The instantiation options for a WebSocketProvider
     */
    constructor(options: WebSocketProvider.IOptions);
    /**
     * Test whether the object has been disposed.
     */
    get isDisposed(): boolean;
    /**
     * A promise that resolves when the document provider is ready.
     */
    get ready(): Promise<void>;
    /**
     * Dispose of the resources held by the object.
     */
    dispose(): void;
    private _onUserChanged;
    private _awareness;
    private _contentType;
    private _format;
    private _isDisposed;
    private _path;
    private _ready;
    private _serverUrl;
    private _ydoc;
    private _yWebsocketProvider;
}
/**
 * A namespace for WebSocketProvider statics.
 */
export declare namespace WebSocketProvider {
    /**
     * The instantiation options for a WebSocketProvider.
     */
    interface IOptions extends IDocumentProviderFactory.IOptions<YDocument<DocumentChange>> {
        /**
         * The server URL
         */
        url: string;
        /**
         * The user data
         */
        user?: User.IManager;
    }
}
